@@ -1,8 +1,16 @@
 .onAttach <- function(libname, pkgname) {
   if (!interactive()) return()
-  dataRetrieval_version = utils::packageVersion("dataRetrieval")
+  dataRetrieval_version <- utils::packageVersion("dataRetrieval")
+  token_message <- ""
+  if(Sys.getenv("API_USGS_PAT") == ""){
+    token_message <- "\nConsider adding an API_USGS_PAT for new USGS functions.
+See: https://api.waterdata.usgs.gov/signup"
+  }
   packageStartupMessage("dataRetrieval ", dataRetrieval_version,"
-Extended Documentation: https://doi-usgs.github.io/dataRetrieval")
+Extended Documentation: https://doi-usgs.github.io/dataRetrieval
+Learn about the new functions that are replacing NWIS functions here:
+https://doi-usgs.github.io/dataRetrieval/articles/read_waterdata_functions.html",
+token_message)
 }
 
 #' Retrieval functions for USGS and EPA data
@@ -15,13 +23,13 @@ Extended Documentation: https://doi-usgs.github.io/dataRetrieval")
 #' that originally came from the United States Geological Survey, an agency of
 #' the United States Department of Interior. For more information, see the
 #' official USGS copyright policy at
-#' \url{https://www.usgs.gov/information-policies-and-instructions/copyrights-and-credits}\cr
+#' <https://www.usgs.gov/information-policies-and-instructions/copyrights-and-credits>\cr
 #' LazyLoad: \tab yes\cr
 #' }
 #'
 #' Retrieval functions for USGS and EPA hydrologic and water quality data.
 #'
-#' Please see \url{https://doi-usgs.github.io/dataRetrieval/} for more information.
+#' Please see <https://doi-usgs.github.io/dataRetrieval/> for more information.
 #'
 #' @name dataRetrieval
 #' @aliases dataRetrieval-package
@@ -60,7 +68,7 @@ NULL
 #' Data to convert USGS parameter code to characteristic names
 #'
 #' Data pulled from Water Quality Portal on December 20, 2021. The data was pulled from
-#' \url{https://www.waterqualitydata.us/Codes/public_srsnames/?mimeType=csv}.
+#' <https://www.waterqualitydata.us/Codes/public_srsnames/?mimeType=csv>.
 #'
 #' @name pCodeToName
 #' @return pCodeToName data frame with information about USGS parameters and how they
@@ -89,9 +97,8 @@ NULL
 
 #' US State Code Lookup Table
 #'
-#' Data originally pulled from \url{https://www2.census.gov/geo/docs/reference/state.txt}
-#' on April 1, 2015. On Feb. 11, 2022, the fields were updated with the
-#' file found in inst/extdata, which is used internally with NWIS retrievals.
+#' Classic lookup table for states. Has been replaced in functions with
+#' `check_waterdata_sample_params("states")`.
 #'
 #' @name stateCd
 #' @return stateCd data frame.
@@ -112,9 +119,8 @@ NULL
 
 #' US County Code Lookup Table
 #'
-#' Data originally pulled from \url{https://www2.census.gov/geo/docs/reference/codes/files/national_county.txt}
-#' on April 1, 2015. On Feb. 11, 2022, the fields were updated with the
-#' file found in inst/extdata, which is used internally with NWIS retrievals.
+#' Classic lookup table for counties. Has been replaced in functions with
+#' `check_waterdata_sample_params("counties")`.
 #'
 #' @name countyCd
 #' @return countyCd data frame.
